==> haskell-quickcheck-classes-0.6.5.0-300-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-quickcheck-classes.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 quickcheck-classes
version:              0.6.5.0
visibility:           public
id:                   quickcheck-classes-0.6.5.0-6W73tEMQzcIIgCOpWIREnH
key:                  quickcheck-classes-0.6.5.0-6W73tEMQzcIIgCOpWIREnH
license:              BSD-3-Clause
copyright:            2018 Andrew Martin
maintainer:           andrew.thaddeus@gmail.com
author:               Andrew Martin, chessai
homepage:             https://github.com/andrewthad/quickcheck-classes#readme
synopsis:             QuickCheck common typeclasses
description:
    This library provides QuickCheck properties to ensure
    that typeclass instances adhere to the set of laws that
    they are supposed to. There are other libraries that do
    similar things, such as `genvalidity-hspec` and `checkers`.
    This library differs from other solutions by not introducing
    any new typeclasses that the user needs to learn.

    /Note:/ on GHC < 8.5, this library uses the higher-kinded typeclasses
    ('\''Data.Functor.Classes.Show1'\'', '\''Data.Functor.Classes.Eq1'\'', '\''Data.Functor.Classes.Ord1'\'', etc.),
    but on GHC >= 8.5, it uses `-XQuantifiedConstraints` to express these
    constraints more cleanly.

category:             Testing
abi:                  7f5599ed9b6f0251a9f43c8585273953
exposed:              True
exposed-modules:
    Test.QuickCheck.Classes Test.QuickCheck.Classes.IsList

hidden-modules:
    Test.QuickCheck.Classes.Alt Test.QuickCheck.Classes.Apply
    Test.QuickCheck.Classes.Euclidean Test.QuickCheck.Classes.Json
    Test.QuickCheck.Classes.MVector Test.QuickCheck.Classes.Plus
    Test.QuickCheck.Classes.Prim Test.QuickCheck.Classes.Semigroupoid
    Test.QuickCheck.Classes.Semiring Test.QuickCheck.Classes.Ring

import-dirs:          /usr/lib/ghc-9.4.8/site-local/quickcheck-classes-0.6.5.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/quickcheck-classes-0.6.5.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/quickcheck-classes-0.6.5.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-quickcheck-classes
hs-libraries:         HSquickcheck-classes-0.6.5.0-6W73tEMQzcIIgCOpWIREnH
depends:
    QuickCheck-2.14.3-J45WF0Yux319EMk6f3cLwH
    aeson-2.1.2.1-Eu0ZMA1fvZJ7acphaZ1YUp base-4.17.2.1 containers-0.6.7
    primitive-0.9.1.0-6oaPYJdlxXvFbCd1QkYYcO
    primitive-addr-0.1.0.3-MrxgNmcygAHtVa5YNttSd
    quickcheck-classes-base-0.6.2.0-25DTy5cmrwpAhuCnTOMbW9
    semigroupoids-6.0.1-Dyiulc79AG72hQ04hyBGLr
    semirings-0.7-DmddLId2cYrBSPgVe1Scp5 transformers-0.5.6.2
    vector-0.13.2.0-2If6MrCrP3g55Bnhb5dowG

haddock-interfaces:
    /usr/share/doc/haskell-quickcheck-classes/html/quickcheck-classes.haddock

haddock-html:         /usr/share/doc/haskell-quickcheck-classes/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-quickcheck-classes-0.6.5.0-301-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-quickcheck-classes.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 quickcheck-classes
version:              0.6.5.0
visibility:           public
id:                   quickcheck-classes-0.6.5.0-8vpBzygOqXIBECuorixMke
key:                  quickcheck-classes-0.6.5.0-8vpBzygOqXIBECuorixMke
license:              BSD-3-Clause
copyright:            2018 Andrew Martin
maintainer:           andrew.thaddeus@gmail.com
author:               Andrew Martin, chessai
homepage:             https://github.com/andrewthad/quickcheck-classes#readme
synopsis:             QuickCheck common typeclasses
description:
    This library provides QuickCheck properties to ensure
    that typeclass instances adhere to the set of laws that
    they are supposed to. There are other libraries that do
    similar things, such as `genvalidity-hspec` and `checkers`.
    This library differs from other solutions by not introducing
    any new typeclasses that the user needs to learn.

    /Note:/ on GHC < 8.5, this library uses the higher-kinded typeclasses
    ('\''Data.Functor.Classes.Show1'\'', '\''Data.Functor.Classes.Eq1'\'', '\''Data.Functor.Classes.Ord1'\'', etc.),
    but on GHC >= 8.5, it uses `-XQuantifiedConstraints` to express these
    constraints more cleanly.

category:             Testing
abi:                  0792b8f2c7c9ef6641f2016285dc13b5
exposed:              True
exposed-modules:
    Test.QuickCheck.Classes Test.QuickCheck.Classes.IsList

hidden-modules:
    Test.QuickCheck.Classes.Alt Test.QuickCheck.Classes.Apply
    Test.QuickCheck.Classes.Euclidean Test.QuickCheck.Classes.Json
    Test.QuickCheck.Classes.MVector Test.QuickCheck.Classes.Plus
    Test.QuickCheck.Classes.Prim Test.QuickCheck.Classes.Semigroupoid
    Test.QuickCheck.Classes.Semiring Test.QuickCheck.Classes.Ring

import-dirs:          /usr/lib/ghc-9.4.8/site-local/quickcheck-classes-0.6.5.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/quickcheck-classes-0.6.5.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/quickcheck-classes-0.6.5.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-quickcheck-classes
hs-libraries:         HSquickcheck-classes-0.6.5.0-8vpBzygOqXIBECuorixMke
depends:
    QuickCheck-2.14.3-CEKfXt0vIE49fVERCVjkfD
    aeson-2.1.2.1-HvDDR856aNq5cfhhuYXFVB base-4.17.2.1 containers-0.6.7
    primitive-0.9.1.0-1qcn44iT2KcGW7CVhBZc50
    primitive-addr-0.1.0.3-3xL4f0MsEPZB0fTfYFmk9Y
    quickcheck-classes-base-0.6.2.0-DLVhYmGFO1r1Em1gIKxwrJ
    semigroupoids-6.0.1-KCNtGml05AHAYKR3WNsoxY
    semirings-0.7-BLQ8EFSRuSyFsCe3eQdAkH transformers-0.5.6.2
    vector-0.13.2.0-4gUGda2ISIbCv9ACnxMPCL

haddock-interfaces:
    /usr/share/doc/haskell-quickcheck-classes/html/quickcheck-classes.haddock

haddock-html:         /usr/share/doc/haskell-quickcheck-classes/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
